@@ -39,9 +39,8 @@ use RDF::Trine::Iterator qw(smap);
 use base qw(RDF::Trine::Iterator);
 
 our ($REVISION, $VERSION, $debug);
-use constant DEBUG	=> 0;
 BEGIN {
-	$debug		= DEBUG;
+	$debug		= 0;
 	$REVISION	= do { my $REV = (qw$Revision: 293 $)[1]; sprintf("%0.3f", 1 + ($REV/1000)) };
 	$VERSION	= '1.000';
 }
@@ -149,7 +148,7 @@ sub join_streams {
 		my $a_sort		= join(',', $a->sorted_by);
 		my $b_sort		= join(',', $b->sorted_by);
 		
-		if (DEBUG) {
+		if ($debug) {
 			warn '---------------------------';
 			warn 'REQUESTED SORT in JOIN: ' . Dumper($req_sort);
 			warn 'JOIN STREAM SORTED BY: ' . Dumper($a_sort);
@@ -157,17 +156,17 @@ sub join_streams {
 		}
 		my $actual_sort;
 		if (substr( $a_sort, 0, length($req_sort) ) eq $req_sort) {
-			warn "first stream is already sorted. using it in the outer loop.\n" if (DEBUG);
+			warn "first stream is already sorted. using it in the outer loop.\n" if ($debug);
 		} elsif (substr( $b_sort, 0, length($req_sort) ) eq $req_sort) {
-			warn "second stream is already sorted. using it in the outer loop.\n" if (DEBUG);
+			warn "second stream is already sorted. using it in the outer loop.\n" if ($debug);
 			($a,$b)	= ($b,$a);
 		} else {
 			my $a_common	= join('!', $a_sort, $req_sort);
 			my $b_common	= join('!', $b_sort, $req_sort);
 			if ($a_common =~ qr[^([^!]+)[^!]*!\1]) {	# shared prefix between $a_sort and $req_sort?
-				warn "first stream is closely sorted ($1).\n" if (DEBUG);
+				warn "first stream is closely sorted ($1).\n" if ($debug);
 			} elsif ($b_common =~ qr[^([^!]+)[^!]*!\1]) {	# shared prefix between $b_sort and $req_sort?
-				warn "second stream is closely sorted ($1).\n" if (DEBUG);
+				warn "second stream is closely sorted ($1).\n" if ($debug);
 				($a,$b)	= ($b,$a);
 			}
 		}
@@ -175,7 +174,7 @@ sub join_streams {
 	}
 	
 	my $stream	= $self->SUPER::join_streams( $a, $b, %args );
-	warn "JOINED stream is sorted by: " . join(',', @join_sorted_by) . "\n" if (DEBUG);
+	warn "JOINED stream is sorted by: " . join(',', @join_sorted_by) . "\n" if ($debug);
 	$stream->{sorted_by}	= \@join_sorted_by;
 	return $stream;
 }
@@ -366,30 +365,61 @@ sub as_xml {
 	
 	my $count	= 0;
 	my $t	= join("\n\t", map { qq(<variable name="$_"/>) } @variables);
-	my $xml	= <<"END";
-<?xml version="1.0"?>
-<sparql xmlns="http://www.w3.org/2001/sw/DataAccess/rf1/result2">
-<head>
-	${t}
-</head>
-<results>
-END
+	my $head	= $t;
+	my $results	= '';
 	while (!$self->finished) {
 		my @row;
-		$xml	.= "\t\t<result>\n";
+		$results	.= "\t\t<result>\n";
 		for (my $i = 0; $i < $width; $i++) {
-			my $name		= $self->binding_name($i);
-			my $value		= $self->binding_value($i);
-			$xml	.= "\t\t\t" . $self->format_node_xml($value, $name) . "\n";
+			my $name	= $self->binding_name($i);
+			my $value	= $self->binding_value($i);
+			$results	.= "\t\t\t" . $self->format_node_xml($value, $name) . "\n";
 		}
-		$xml	.= "\t\t</result>\n";
+		$results	.= "\t\t</result>\n";
 		
 		last if ($max_result_size and ++$count >= $max_result_size);
 	} continue { $self->next_result }
-	$xml	.= <<"EOT";
-</results>
+	
+	if (my $extra = $self->extra_result_data) {
+		my $extraxml	= '';
+		foreach my $tag (keys %$extra) {
+			$extraxml	.= qq[<extra name="${tag}">\n];
+			my $value	= $extra->{ $tag };
+			foreach my $e (@$value) {
+				foreach my $k (keys %$e) {
+					my $v		= $e->{ $k };
+					my @values	= @$v;
+					foreach ($k, @values) {
+						s/&/&amp;/g;
+						s/</&lt;/g;
+						s/"/&quot;/g;
+					}
+					$extraxml	.= qq[\t<extrakey id="$k">] . join(',', @values) . qq[</extrakey>\n];
+				}
+			}
+			$extraxml	.= "</extra>\n";
+		}
+		my $u	= URI->new('data:');
+		$u->media_type('text/xml');
+		$u->data($extraxml);
+		my $uri	= "$u";
+		$uri	=~ s/&/&amp;/g;
+		$uri	=~ s/</&lt;/g;
+		$uri	=~ s/'/&apos;/g;
+		$uri	=~ s/"/&quot;/g;
+		$head	.= qq[\n\t<link href="$uri" />\n];
+	}
+	
+	my $xml	= <<"END";
+<?xml version="1.0"?>
+<sparql xmlns="http://www.w3.org/2005/sparql-results#">
+<head>
+	${head}
+</head>
+<results>
+${results}</results>
 </sparql>
-EOT
+END
 	return $xml;
 }
 
