@@ -1,29 +1,24 @@
 # RDF::Trine::Iterator::Graph
+# -------------
+# $Revision $
+# $Date $
 # -----------------------------------------------------------------------------
 
 =head1 NAME
 
-RDF::Trine::Iterator::Graph - Iterator class for graph query results
-
-=head1 VERSION
-
-This document describes RDF::Trine::Iterator::Graph version 0.999_02
+RDF::Trine::Iterator::Graph - Stream (iterator) class for graph query results.
 
 =head1 SYNOPSIS
 
- use RDF::Trine::Iterator::Graph;
- 
- my $iterator = RDF::Trine::Iterator::Graph->new( \&data );
- while (my $st = $iterator->next) {
-   # $st is a RDF::Trine::Statement object
-   print $st->as_string;
- }
+    use RDF::Trine::Iterator;
+    
+    my $iterator = RDF::Trine::Iterator::Graph->new( \&data );
+    while (my $statement = $iterator->next) {
+    	# do something with $statement
+    }
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Trine::Iterator> class.
-
 =over 4
 
 =cut
@@ -42,17 +37,14 @@ use RDF::Trine::Iterator qw(sgrep);
 use RDF::Trine::Iterator::Graph::Materialized;
 
 use base qw(RDF::Trine::Iterator);
-
-######################################################################
-
-our ($VERSION);
+our ($REVISION, $VERSION, $debug);
+use constant DEBUG	=> 0;
 BEGIN {
-	$VERSION	= '0.999_02';
+	$debug		= DEBUG;
+	$REVISION	= do { my $REV = (qw$Revision: 293 $)[1]; sprintf("%0.3f", 1 + ($REV/1000)) };
+	$VERSION	= '1.000';
 }
 
-######################################################################
-
-
 =item C<new ( \@results, %args )>
 
 =item C<new ( \&results, %args )>
@@ -69,7 +61,7 @@ $type should be one of: bindings, boolean, graph.
 sub new {
 	my $class		= shift;
 	my $stream		= shift || sub { undef };
-# 	Carp::confess unless (scalar(@_) % 2 == 0);
+	Carp::confess unless (scalar(@_) % 2 == 0);
 	my %args		= @_;
 	
 	my $type		= 'graph';
@@ -97,24 +89,16 @@ sub as_bindings {
 	my @nodes	= @_;
 	my @names	= qw(subject predicate object context);
 	my %bindings;
-	foreach my $i (0 .. $#names) {
-		if (not($nodes[ $i ]) or not($nodes[ $i ]->isa('RDF::Trine::Node::Variable'))) {
-			$nodes[ $i ]	= RDF::Trine::Node::Variable->new( $names[ $i ] );
-		}
-	}
 	foreach my $i (0 .. $#nodes) {
 		my $n	= $nodes[ $i ];
-		$bindings{ $n->name }	= $names[ $i ];
+		if (blessed($n) and $n->isa( 'RDF::Trine::Node::Variable' )) {
+			$bindings{ $n->name }	= $names[ $i ];
+		}
 	}
-	my $context	= $nodes[ 3 ]->name;
-	
 	my $sub	= sub {
 		my $statement	= $self->next;
 		return undef unless ($statement);
-		my %values		= map {
-			my $method = $bindings{ $_ };
-			$_ => $statement->$method()
-		} grep { ($statement->isa('RDF::Trine::Statement::Quad')) ? 1 : ($_ ne $context) } (keys %bindings);
+		my %values		= map { my $method = $bindings{ $_ }; $_ => $statement->$method() } (keys %bindings);
 		return \%values;
 	};
 	return RDF::Trine::Iterator::Bindings->new( $sub, [ keys %bindings ] );
@@ -123,9 +107,6 @@ sub as_bindings {
 =item C<< materialize >>
 
 Returns a materialized version of the current graph iterator.
-The materialization process will leave this iterator empty. The materialized
-iterator that is returned should be used for any future need for the iterator's
-data.
 
 =cut
 
@@ -149,7 +130,7 @@ serialization methods assume the results are unique, and so use this method
 before serialization.
 
 Uniqueness is opt-in for efficiency concerns -- this method requires O(n) memory,
-and so may have noticeable effects on large graphs.
+and so may have noticable effects on large graphs.
 
 =cut
 
@@ -176,57 +157,6 @@ sub is_graph {
 	return 1;
 }
 
-=item C<as_string ( $max_size [, \$count] )>
-
-Returns a string table serialization of the stream data.
-
-=cut
-
-sub as_string {
-	my $self			= shift;
-	my $max_result_size	= shift || 0;
-	my $rescount		= shift;
-	my @names			= qw(subject predicate object);
-	my $headers			= \@names;
-	my @rows;
-	my $count	= 0;
-	while (my $row = $self->next) {
-		push(@rows, [ map { blessed($_) ? $_->as_string : '' } map { $row->$_() } qw(subject predicate object) ]);
-		last if ($max_result_size and ++$count >= $max_result_size);
-	}
-#	my $rows			= [ map { [ map { blessed($_) ? $_->as_string : '' } @{$_}{ @names } ] } @nodes ];
-	if (ref($rescount)) {
-		$$rescount	= scalar(@rows);
-	}
-	
-	my @rule			= qw(- +);
-	my @headers			= (\q"| ");
-	push(@headers, map { $_ => \q" | " } @$headers);
-	pop	@headers;
-	push @headers => (\q" |");
-	
-	if ('ARRAY' eq ref $rows[0]) {
-		if (@$headers == @{ $rows[0] }) {
-			my $table = Text::Table->new(@headers);
-			$table->rule(@rule);
-			$table->body_rule(@rule);
-			$table->load(@rows);
-		
-			return join('',
-					$table->rule(@rule),
-					$table->title,
-					$table->rule(@rule),
-					map({ $table->body($_) } 0 .. @rows),
-					$table->rule(@rule)
-				);
-		} else {
-			die("make_table() rows must be an AoA with rows being same size as headers");
-		}
-	} else {
-		return '';
-	}
-}
-
 =item C<as_xml ( $max_size )>
 
 Returns an XML serialization of the stream data.
@@ -234,30 +164,13 @@ Returns an XML serialization of the stream data.
 =cut
 
 sub as_xml {
-	my $self	= shift;
-	my $max_result_size	= shift || 0;
-	my $string	= '';
-	open( my $fh, '>', \$string );
-	$self->print_xml( $fh, $max_result_size );
-	return $string;
-}
-
-=item C<< print_xml ( $fh, $max_size ) >>
-
-Prints an XML serialization of the stream data to the filehandle $fh.
-
-=cut
-
-sub print_xml {
 	my $self			= shift;
-	my $fh				= shift;
 	my $max_result_size	= shift || 0;
+# 	my $bridge			= $self->_bridge;
 	my $graph			= $self->unique();
-	binmode($fh, ':utf8');
 	
 	my $count	= 0;
-	no strict 'refs';
-	print {$fh} <<"END";
+	my $xml		= <<"END";
 <?xml version="1.0" encoding="utf-8"?>
 <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
 END
@@ -275,13 +188,13 @@ END
 					: 'rdf:nodeID="' . $subject->blank_identifier . '"';
 		my $object	= $stmt->object;
 		
-		print {$fh} qq[<rdf:Description $subjstr>\n];
+		$xml		.= qq[<rdf:Description $subjstr>\n];
 		if ($object->is_resource) {
 			my $uri	= $object->uri_value;
-			print {$fh} qq[\t<${local} xmlns="${ns}" rdf:resource="$uri"/>\n];
-		} elsif ($object->isa('RDF::Trine::Node::Blank')) {
+			$xml	.= qq[\t<${local} xmlns="${ns}" rdf:resource="$uri"/>\n];
+		} elsif ($object->is_blank) {
 			my $id	= $object->blank_identifier;
-			print {$fh} qq[\t<${local} xmlns="${ns}" rdf:nodeID="$id"/>\n];
+			$xml	.= qq[\t<${local} xmlns="${ns}" rdf:nodeID="$id"/>\n];
 		} else {
 			my $value	= $object->literal_value;
 			# escape < and & and ' and " and >
@@ -299,11 +212,12 @@ END
 				my $dt	= $object->literal_datatype;
 				$tag	.= qq[ rdf:datatype="${dt}"];
 			}
-			print {$fh} qq[\t<${tag}>${value}</${local}>\n];
+			$xml	.= qq[\t<${tag}>${value}</${local}>\n];
 		}
-		print {$fh} qq[</rdf:Description>\n];
+		$xml		.= qq[</rdf:Description>\n];
 	}
-	print {$fh} "</rdf:RDF>\n";
+	$xml	.= "</rdf:RDF>\n";
+	return $xml;
 }
 
 =item C<as_json ( $max_size )>
@@ -314,49 +228,10 @@ Returns a JSON serialization of the stream data.
 
 sub as_json {
 	my $self			= shift;
-	my $max_result_size	= shift;
+	my $max_result_size	= shift || 0;
 	throw RDF::Trine::Error::SerializationError ( -text => 'There is no JSON serialization specified for graph query results' );
 }
 
-=item C<< as_hashref >>
-
-Returns a hashref representing the model in an RDF/JSON-like manner.
-
-See C<< as_hashref >> at L<RDF::Trine::Model> for full documentation of the
-hashref format.
-
-=cut
-
-sub as_hashref {
-	my $self = shift;
-	my $index = {};
-	while (my $statement = $self->next) {
-		
-		my $s = $statement->subject->isa('RDF::Trine::Node::Blank') ? 
-			('_:'.$statement->subject->blank_identifier) :
-			$statement->subject->uri ;
-		my $p = $statement->predicate->uri ;
-		
-		my $o = {};
-		if ($statement->object->isa('RDF::Trine::Node::Literal')) {
-			$o->{'type'}		= 'literal';
-			$o->{'value'}		= $statement->object->literal_value;
-			$o->{'lang'}		= $statement->object->literal_value_language
-				if $statement->object->has_language;
-			$o->{'datatype'}	= $statement->object->literal_datatype
-				if $statement->object->has_datatype;
-		} else {
-			$o->{'type'}		= $statement->object->isa('RDF::Trine::Node::Blank') ? 'bnode' : 'uri';
-			$o->{'value'}		= $statement->object->isa('RDF::Trine::Node::Blank') ? 
-				('_:'.$statement->object->blank_identifier) :
-				$statement->object->uri ;
-		}
-
-		push @{ $index->{$s}->{$p} }, $o;
-	}
-	return $index;
-}
-
 =item C<< construct_args >>
 
 Returns the arguments necessary to pass to the stream constructor _new
@@ -384,19 +259,17 @@ L<JSON|JSON>
 
 L<Scalar::Util|Scalar::Util>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/perlrdf/issues>.
 
 =head1 AUTHOR
 
-Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
+Gregory Todd Williams  C<< <greg@evilfunhouse.com> >>
 
-=head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
-program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+=head1 LICENCE AND COPYRIGHT
+
+Copyright (c) 2007, Gregory Todd Williams C<< <gwilliams@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 
-=cut
