@@ -1,14 +1,13 @@
 # RDF::Trine::Node::Variable
+# -------------
+# $Revision: 121 $
+# $Date: 2006-02-06 23:07:43 -0500 (Mon, 06 Feb 2006) $
 # -----------------------------------------------------------------------------
 
 =head1 NAME
 
 RDF::Trine::Node::Variable - RDF Node class for variables
 
-=head1 VERSION
-
-This document describes RDF::Trine::Node::Variable version 0.999_02
-
 =cut
 
 package RDF::Trine::Node::Variable;
@@ -24,21 +23,16 @@ use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '0.999_02';
+	$debug		= 0;
+	$VERSION	= do { my $REV = (qw$Revision: 121 $)[1]; sprintf("%0.3f", 1 + ($REV/1000)) };
 }
 
 ######################################################################
 
-use overload	'""'	=> sub { $_[0]->sse },
-			;
-
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Trine::Node> class.
-
 =over 4
 
 =cut
@@ -78,6 +72,17 @@ sub sse {
 	return qq(?${name});
 }
 
+=item C<< as_sparql >>
+
+Returns the SPARQL string for this node.
+
+=cut
+
+sub as_sparql {
+	my $self	= shift;
+	return $self->sse;
+}
+
 =item C<< as_string >>
 
 Returns a string representation of the node.
@@ -89,28 +94,6 @@ sub as_string {
 	return '?' . $self->name;
 }
 
-=item C<< value >>
-
-Returns the variable name.
-
-=cut
-
-sub value {
-	my $self	= shift;
-	return $self->name;
-}
-
-=item C<< as_ntriples >>
-
-Returns the node in a string form suitable for NTriples serialization.
-
-=cut
-
-sub as_ntriples {
-	my $self	= shift;
-	throw RDF::Trine::Error::UnimplementedError -text => "Variable nodes aren't allowed in NTriples";
-}
-
 =item C<< type >>
 
 Returns the type string of this node.
@@ -135,12 +118,6 @@ sub equal {
 	return ($self->name eq $node->name);
 }
 
-# called to compare two nodes of the same type
-sub _compare {
-	my $a	= shift;
-	my $b	= shift;
-	return ($a->name cmp $b->name);
-}
 
 1;
 
@@ -148,19 +125,8 @@ __END__
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/perlrdf/issues>.
-
 =head1 AUTHOR
 
-Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2006-2012 Gregory Todd Williams. This
-program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+ Gregory Todd Williams <gwilliams@cpan.org>
 
 =cut
